"""
GoComics Scraper
~~~~~~~~~~~~~~~~~~~

A basic scraper for GoComics.

:copyright: (c) 2022 Omkaar
:license: MIT, see LICENSE for more details.
"""


__title__ = 'gocomics'
__author__ = 'Omkaar'
__license__ = 'MIT'
__copyright__ = 'Copyright 2022 Omkaar'
__version__ = '1.1.4'


from .comic import *
from .list import *
from .utils import *
